==> TestCaseAndMakefile-1.0.1-1.tar.gz: TestMain.cpp <==
#include "include/AnalysisModuleInterface.h"
#include "include/InOutPin.h"
#include "AnalysisNotifyModule.h"
#include "AnalysisModuleManager.h"

int main()
{
	CAnalysisNotifyModule	AnalysisNotifyModule;
	CAnalysisModuleManager	AnalysisModuleManager;
	CSourceFilePin 		SourceFilePin;
	CAnalysisResultPin	AnalysisResultPin;
	CModuleInfo* 		pInfo = NULL;
	
	int 			nFileNameSize	= 0;

	char szModuleDir[] = "/root/OSS/CVS/StaticAnalysisTool/Modules/";
	// char szTestSourceFileName[] = "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test2.c,/root/OSS/CVS/StaticAnalysisTool/TestFile/Test4.c,/root/OSS/CVS/StaticAnalysisTool/TestFile/Test5.c";
	// char szTestSourceFileName[] = "/root/OSS/CVS/StaticAnalysisTool/TestFile/heap.c";
	char szTestSourceFileName[] = "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test1.c";

	AnalysisModuleManager.Initialize( &AnalysisNotifyModule , szModuleDir );
	AnalysisModuleManager.LoadModules();

	for( AnalysisModuleManager.Begin() ; false == AnalysisModuleManager.IsEnd() ; AnalysisModuleManager.NextIterator() )
	{
		pInfo = AnalysisModuleManager.GetIterator();
		if( pInfo )
		{
			/*
 			printf( "-- In Test Main--\n" );
			printf( "Module Id = %d , Rv = %d , Name = %s\n" , pInfo->m_uiId , pInfo->m_uiRevisionNo , pInfo->m_szName );
			printf( "Input Id = %d , Name = %s\n" , pInfo->m_uiInputId , pInfo->m_szInputName );
			printf( "Output Id = %d , Name = %s\n" , pInfo->m_uiOutputId , pInfo->m_szOutputName ); 
			*/
						
			AnalysisModuleManager.InsertModuleIntoGraph( pInfo );
		}
	}

	/* AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 1 );
	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 2 ); */

	/* AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 1 );	
	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 2 );  */
	/*
 * 	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 3 , 4 ); */
	
	/* AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 5 );
	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 5 , 6 ); 
	
	
 	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 1 ); */
	/* AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 2 ); */
	

	// AnalysisModuleManager.m_ModuleGraph.ConnectModule( 3 , 2 );	
	// AnalysisModuleManager.m_ModuleGraph.ConnectModule( 3 , 2 );
	
	nFileNameSize = strlen( szTestSourceFileName );
	SourceFilePin.m_pszFileName = new char[ nFileNameSize + 1 ];
	memset( SourceFilePin.m_pszFileName , 0 , nFileNameSize  + 1 );

	strncpy( SourceFilePin.m_pszFileName , szTestSourceFileName  , strlen( szTestSourceFileName ) );
	// SourceFilePin.m_nFileCount = 2;
	SourceFilePin.m_nFileCount = 1;
	AnalysisModuleManager.StartAnalysisProcess( &SourceFilePin ); 

	/* strncpy( SourceFilePin.m_pszFileName , "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test2.c"  , strlen( szTestSourceFileName ) );
	SourceFilePin.m_nFileCount = 1;
	AnalysisModuleManager.StartAnalysisProcess( &SourceFilePin ); */

	/* strncpy( SourceFilePin.m_pszFileName , "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test3.c"  , strlen( szTestSourceFileName ) );
	SourceFilePin.m_nFileCount = 1;
	AnalysisModuleManager.StartAnalysisProcess( &SourceFilePin ); 

	strncpy( SourceFilePin.m_pszFileName , "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test4.c"  , strlen( szTestSourceFileName ) );
	SourceFilePin.m_nFileCount = 1;
	AnalysisModuleManager.StartAnalysisProcess( &SourceFilePin ); */
	
	printf( "Exit( 0 )\n" );

	return 0;
}

==> TestCaseAndMakefile-1.1.3-1.tar.gz: TestMain.cpp <==
#include "include/AnalysisModuleInterface.h"
#include "include/InOutPin.h"
#include "AnalysisNotifyModule.h"
#include "AnalysisModuleManager.h"

int main()
{
	CAnalysisNotifyModule	AnalysisNotifyModule;
	CAnalysisModuleManager	AnalysisModuleManager;
	CSourceFilePin 		SourceFilePin;
	CAnalysisResultPin	AnalysisResultPin;
	CModuleInfo* 		pInfo = NULL;
	
	int 			nFileNameSize	= 0;

	//char szModuleDir[] = "/root/OSS/CVS/StaticAnalysisTool/Modules/";
	char szModuleDir[] = "/root/StaticAnalysisTool/Modules/";
	// char szTestSourceFileName[] = "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test2.c,/root/OSS/CVS/StaticAnalysisTool/TestFile/Test4.c,/root/OSS/CVS/StaticAnalysisTool/TestFile/Test5.c";
	// char szTestSourceFileName[] = "/root/OSS/CVS/StaticAnalysisTool/TestFile/heap.c";
	//char szTestSourceFileName[] = "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test1.c";
	char szTestSourceFileName[] = "/root/StaticAnalysisTool/TestFile/Test4.c";

	AnalysisModuleManager.Initialize( &AnalysisNotifyModule , szModuleDir );
	AnalysisModuleManager.LoadModules();

	for( AnalysisModuleManager.Begin() ; false == AnalysisModuleManager.IsEnd() ; AnalysisModuleManager.NextIterator() )
	{
		pInfo = AnalysisModuleManager.GetIterator();
		if( pInfo )
		{
			/*
 			printf( "-- In Test Main--\n" );
			printf( "Module Id = %d , Rv = %d , Name = %s\n" , pInfo->m_uiId , pInfo->m_uiRevisionNo , pInfo->m_szName );
			printf( "Input Id = %d , Name = %s\n" , pInfo->m_uiInputId , pInfo->m_szInputName );
			printf( "Output Id = %d , Name = %s\n" , pInfo->m_uiOutputId , pInfo->m_szOutputName ); 
			*/
						
			AnalysisModuleManager.InsertModuleIntoGraph( pInfo );
		}
	}

	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 1 );
	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 2 ); 

	/* AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 1 );	
	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 2 );  */
	/*
 * 	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 3 , 4 ); */
	
	/* AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 5 );
	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 5 , 6 ); 
	
	
 	AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 1 ); */
	/* AnalysisModuleManager.m_ModuleGraph.ConnectModule( 0 , 2 ); */
	

	// AnalysisModuleManager.m_ModuleGraph.ConnectModule( 3 , 2 );	
	// AnalysisModuleManager.m_ModuleGraph.ConnectModule( 3 , 2 );
	
	nFileNameSize = strlen( szTestSourceFileName );
	SourceFilePin.m_pszFileName = new char[ nFileNameSize + 1 ];
	memset( SourceFilePin.m_pszFileName , 0 , nFileNameSize  + 1 );

	strncpy( SourceFilePin.m_pszFileName , szTestSourceFileName  , strlen( szTestSourceFileName ) );
	// SourceFilePin.m_nFileCount = 2;
	SourceFilePin.m_nFileCount = 1;
	AnalysisModuleManager.StartAnalysisProcess( &SourceFilePin ); 

	/* strncpy( SourceFilePin.m_pszFileName , "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test2.c"  , strlen( szTestSourceFileName ) );
	SourceFilePin.m_nFileCount = 1;
	AnalysisModuleManager.StartAnalysisProcess( &SourceFilePin ); */

	/* strncpy( SourceFilePin.m_pszFileName , "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test3.c"  , strlen( szTestSourceFileName ) );
	SourceFilePin.m_nFileCount = 1;
	AnalysisModuleManager.StartAnalysisProcess( &SourceFilePin ); 

	strncpy( SourceFilePin.m_pszFileName , "/root/OSS/CVS/StaticAnalysisTool/TestFile/Test4.c"  , strlen( szTestSourceFileName ) );
	SourceFilePin.m_nFileCount = 1;
	AnalysisModuleManager.StartAnalysisProcess( &SourceFilePin ); */
	
	printf( "Exit( 0 )\n" );

	return 0;
}
